//-------------------------------------------------------------------//
// BleederEffectSpawner                                              //
// this class handles the spawning of the bleeding effect on players //
//-------------------------------------------------------------------//

class BleederEffectSpawner extends Actor config(MoreBlood);

var() config int MBdefHealth;     // set to players default or starting health.  default 100
var float SpawnDelay;		// time between effect spawns
var int SpawnsLeft;		// number of effects left to spawn before the spawner is destroyed
var bool bIsSpawning;		// flag to check whether spawner is active
var vector RelLocation;		// the location of the spawner relative to the location of the owner
var class<Effects> EffectToSpawn;	// the effect we want to spawn

function StopSpawner()
{
	SetTimer(0.0, false);
	bIsSpawning = false;
}

function StartSpawner()
{
	if (bIsSpawning)
	{
		StopSpawner();
	}
	bIsSpawning = true;
	SetTimer(SpawnDelay, true);
	if (class'MoreBloodConfig'.Default.bDebugMode)
	{
		log("Owner.Location: "@Owner.Location$"   Location: "@Location$"   Relocation: "@RelLocation);
		log(".");
	}
}

function InitSpawner()
{
	RelLocation = Location - Owner.Location;
}

function SetSpawnProperties(optional float SD, optional int SL, optional class<Effects> E)
{
	if ((Location.Z != 0.0) && (RelLocation.Z != 0.0))
	{
		SpawnDelay = FMin(SD, 5.0);
		SpawnsLeft = Min(SL, 512);
		EffectToSpawn = E;
		StartSpawner();
	}
}

function Timer()
{
	if ((Owner != None) && (bIsSpawning))
	{
		SpawnsLeft--;
		if ((SpawnsLeft <= 0) || (Pawn(Owner).health == MBdefHealth))
		{
			StopSpawner();
			Destroy();
		}
		else
			Spawn(EffectToSpawn, Self, , RelLocation + Owner.Location, Owner.Rotation);
	}
}

defaultproperties
{
	bHidden=True
	MBdefHealth=100
}
